Package: CDSS
Type: Package
Title: Course-Dependent Skill Structures
Version: 0.3-1
Date: 2026-04-15
Depends: R (>= 4.3.0)
Imports: readODS (>= 2.0.0), openxlsx (>= 4.2.0)
Authors@R: c(person(given = "Cord", family = "Hockemeyer",
                    role = c("aut", "cre"),
                    email = "cord.hockemeyer@uni-graz.at"))
Maintainer: Cord Hockemeyer <cord.hockemeyer@uni-graz.at>
License: GPL-3
NeedsCompilation: no
Description: Deriving skill structures from skill assignment 
    data for courses (sets of learning objects).
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: litedown, DiagrammeRsvg, rsvg, png, kstMatrix
VignetteBuilder: litedown
Packaged: 2026-04-27 04:23:00 UTC; hockemey
Author: Cord Hockemeyer [aut, cre]
Repository: CRAN
Date/Publication: 2026-04-27 05:20:02 UTC
Built: R 4.5.2; ; 2026-04-27 09:36:07 UTC; unix
