# Generated by roxygen2: do not edit by hand

export(cdss_binary_matrix_product)
export(cdss_circular_requirements)
export(cdss_close_ar)
export(cdss_csma2sf)
export(cdss_lo_csma2sf)
export(cdss_lo_sa2af)
export(cdss_lo_sa2ar)
export(cdss_missing_los)
export(cdss_nonteaching_los)
export(cdss_read_skill_assignment_csv)
export(cdss_read_skill_assignment_ods)
export(cdss_read_skill_assignment_xlsx)
export(cdss_reduce_sf)
export(cdss_sa2ar_skill)
export(cdss_sa2sma)
export(cdss_sa_compliance)
export(cdss_sa_describes_sr)
export(cdss_sma2csma)
export(cdss_tables2sa)
export(cdss_wf_read_skill_assignment)
importFrom(openxlsx,read.xlsx)
importFrom(readODS,read_ods)
importFrom(tools,file_ext)
importFrom(utils,read.csv)
